@@ -80,7 +80,7 @@ module Sidekiq
 
     # See https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4
     def user_preferred_languages
-      languages = env['HTTP_ACCEPT_LANGUAGE'.freeze]
+      languages = env['HTTP_ACCEPT_LANGUAGE']
       languages.to_s.downcase.gsub(/\s+/, '').split(',').map do |language|
         locale, quality = language.split(';q=', 2)
         locale  = nil if locale == '*' # Ignore wildcards
@@ -121,7 +121,7 @@ module Sidekiq
     end
 
     def t(msg, options={})
-      string = get_locale[msg] || msg
+      string = get_locale[msg] || strings('en')[msg] || msg
       if options.empty?
         string
       else
@@ -148,11 +148,14 @@ module Sidekiq
     end
 
     def redis_connection
-      Sidekiq.redis { |conn| conn.client.id }
+      Sidekiq.redis do |conn|
+        c = conn.connection
+        "redis://#{c[:location]}/#{c[:db]}"
+      end
     end
 
     def namespace
-      @@ns ||= Sidekiq.redis { |conn| conn.respond_to?(:namespace) ? conn.namespace : nil }
+      @ns ||= Sidekiq.redis { |conn| conn.respond_to?(:namespace) ? conn.namespace : nil }
     end
 
     def redis_info
@@ -181,7 +184,7 @@ module Sidekiq
     end
 
     def parse_params(params)
-      score, jid = params.split("-")
+      score, jid = params.split("-", 2)
       [score.to_f, jid]
     end
 
